<?php

namespace EventPortal\Http\Controllers\Admin\Event;

use EventPortal\Contracts\Event;
use EventPortal\Domain\Component\Button;
use EventPortal\Domain\Table\Facades\Table;
use EventPortal\Domain\Util\AdminRender;
use EventPortal\Enums\InertiaMethod;
use EventPortal\Http\Controllers\Controller;
use Illuminate\Database\Eloquent\Builder;
use Inertia\Response;

class AwaitingLineManagerApprovalController extends Controller
{
    public function __construct()
    {
        $this->middleware('check-permission:event.awaiting-line-manager-approval')->only('index');
    }

    public function index(): Response
    {
        $table = Table::make('line-manager-event.index')
            ->query(
                resolve(Event::class)::query()
                    ->whereHas('approval', function (Builder $query) {
                        $approvalStatus = request()->has('filter.status');

                        if ($approvalStatus) {
                            return $query->whereStatus(request()->input('filter.status'));
                        }

                        return $query->actionableByLineManager();
                    })
                    ->isNotArchived()
                    ->forAdminInTeam()
            )
            ->get();

        return AdminRender::component('Admin/Event/Index')
            ->key('event.index')
            ->withTable($table)
            ->get();
    }
}
