<?php

namespace EventPortal\Tests\Support\Traits;

use Illuminate\Database\Eloquent\Model;

trait IsAudited
{
    /**
     * Assert that changes to the model are audited
     *
     * @param string $modelPath
     * @param array $oldAttributes
     * @param array $newAttributes
     * @return static
     */
    public function assertAudited(string $modelPath, array $oldAttributes, array $newAttributes)
    {
        config(['audit.console' => true]);

        $model = factory($modelPath)->create($oldAttributes);

        $this->assertCount(1, $model->audits);

        $createdAudit = $model->audits->first();

        $this->assertEmpty($this->jsonDecodeValues($createdAudit->old_values));
        $this->assertNotEmpty($this->jsonDecodeValues($createdAudit->new_values));

        $model->update($newAttributes);
        $model->refresh();

        $this->assertCount(2, $model->audits);

        $updatedAudit = $model->audits->last();

        $this->assertArraySubset($oldAttributes, $this->jsonDecodeValues($updatedAudit->old_values));
        $this->assertArraySubset($newAttributes, $this->jsonDecodeValues($updatedAudit->new_values));

        config(['audit.console' => false]);

        return $this;
    }

    /**
     * Run json_decode over each of the original values, so JSON can be compared.
     *
     * @param array $originalValues
     * @return array
     */
    protected function jsonDecodeValues(array $originalValues): array
    {
        return collect($originalValues)
            ->map(function ($value) {
                return json_decode($value) ?? $value;
            })->all();
    }
}
